# Resource Templates

This directory contains templates that can be used as a base for resource
definitions for the CSE's resource importer. 

Most resources are rather complete, but the *fcnt.json* is just a skeleton for more complex *flexContainer*-based resources. 

Some of the attributes are optional, but it makes sense to provide them for importing. To build a resource tree, for example, it is important to know the parent ID *pi*, so one can provide the resource identifier *ri* as well.